@@ -23,7 +23,7 @@ class Blueprint(AbstractModel):
 
     def __init__(self):
         """
-        :param BlueprintId: 镜像 ID  ，是 blueprint 的唯一标识。
+        :param BlueprintId: 镜像 ID  ，是 Blueprint 的唯一标识。
         :type BlueprintId: str
         :param DisplayTitle: 镜像对外展示标题。
         :type DisplayTitle: str
@@ -37,14 +37,24 @@ class Blueprint(AbstractModel):
         :type Platform: str
         :param PlatformType: 操作系统平台类型，如 LINUX_UNIX、WINDOWS。
         :type PlatformType: str
-        :param BlueprintType: 镜像类型，如 APP_OS、PURE_OS。
+        :param BlueprintType: 镜像类型，如 APP_OS、PURE_OS、PRIVATE。
         :type BlueprintType: str
         :param ImageUrl: 镜像图片 URL。
         :type ImageUrl: str
-        :param RequiredSystemDiskSize: 镜像所需系统盘大小
+        :param RequiredSystemDiskSize: 镜像所需系统盘大小。
         :type RequiredSystemDiskSize: int
-        :param BlueprintState: 镜像状态，取值：ONLINE、OFFLINE
+        :param BlueprintState: 镜像状态。
         :type BlueprintState: str
+        :param CreatedTime: 创建时间。按照 ISO8601 标准表示，并且使用 UTC 时间。 
+格式为： YYYY-MM-DDThh:mm:ssZ。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CreatedTime: str
+        :param BlueprintName: 镜像名称。
+        :type BlueprintName: str
+        :param SupportAutomationTools: 镜像是否支持自动化助手。
+        :type SupportAutomationTools: bool
+        :param RequiredMemorySize: 镜像所需内存大小, 单位: GB
+        :type RequiredMemorySize: int
         """
         self.BlueprintId = None
         self.DisplayTitle = None
@@ -57,6 +67,10 @@ class Blueprint(AbstractModel):
         self.ImageUrl = None
         self.RequiredSystemDiskSize = None
         self.BlueprintState = None
+        self.CreatedTime = None
+        self.BlueprintName = None
+        self.SupportAutomationTools = None
+        self.RequiredMemorySize = None
 
 
     def _deserialize(self, params):
@@ -71,6 +85,10 @@ class Blueprint(AbstractModel):
         self.ImageUrl = params.get("ImageUrl")
         self.RequiredSystemDiskSize = params.get("RequiredSystemDiskSize")
         self.BlueprintState = params.get("BlueprintState")
+        self.CreatedTime = params.get("CreatedTime")
+        self.BlueprintName = params.get("BlueprintName")
+        self.SupportAutomationTools = params.get("SupportAutomationTools")
+        self.RequiredMemorySize = params.get("RequiredMemorySize")
 
 
 class Bundle(AbstractModel):
@@ -110,6 +128,11 @@ class Bundle(AbstractModel):
 取值范围：
 <li> GENERAL_BUNDLE：通用型</li><li> STORAGE_BUNDLE：存储型 </li>
         :type BundleType: str
+        :param BundleDisplayLabel: 套餐展示标签.
+取值范围:
+"ACTIVITY": 活动套餐,
+"NORMAL": 普通套餐
+        :type BundleDisplayLabel: str
         """
         self.BundleId = None
         self.Memory = None
@@ -124,6 +147,7 @@ class Bundle(AbstractModel):
         self.InternetChargeType = None
         self.BundleSalesState = None
         self.BundleType = None
+        self.BundleDisplayLabel = None
 
 
     def _deserialize(self, params):
@@ -142,6 +166,7 @@ class Bundle(AbstractModel):
         self.InternetChargeType = params.get("InternetChargeType")
         self.BundleSalesState = params.get("BundleSalesState")
         self.BundleType = params.get("BundleType")
+        self.BundleDisplayLabel = params.get("BundleDisplayLabel")
 
 
 class CreateFirewallRulesRequest(AbstractModel):
@@ -155,9 +180,12 @@ class CreateFirewallRulesRequest(AbstractModel):
         :type InstanceId: str
         :param FirewallRules: 防火墙规则列表。
         :type FirewallRules: list of FirewallRule
+        :param FirewallVersion: 防火墙当前版本。用户每次更新防火墙规则时版本会自动加1，防止规则已过期，不填不考虑冲突。
+        :type FirewallVersion: int
         """
         self.InstanceId = None
         self.FirewallRules = None
+        self.FirewallVersion = None
 
 
     def _deserialize(self, params):
@@ -168,6 +196,7 @@ class CreateFirewallRulesRequest(AbstractModel):
                 obj = FirewallRule()
                 obj._deserialize(item)
                 self.FirewallRules.append(obj)
+        self.FirewallVersion = params.get("FirewallVersion")
 
 
 class CreateFirewallRulesResponse(AbstractModel):
@@ -198,9 +227,12 @@ class DeleteFirewallRulesRequest(AbstractModel):
         :type InstanceId: str
         :param FirewallRules: 防火墙规则列表。
         :type FirewallRules: list of FirewallRule
+        :param FirewallVersion: 防火墙当前版本。用户每次更新防火墙规则时版本会自动加1，防止规则已过期，不填不考虑冲突。
+        :type FirewallVersion: int
         """
         self.InstanceId = None
         self.FirewallRules = None
+        self.FirewallVersion = None
 
 
     def _deserialize(self, params):
@@ -211,6 +243,7 @@ class DeleteFirewallRulesRequest(AbstractModel):
                 obj = FirewallRule()
                 obj._deserialize(item)
                 self.FirewallRules.append(obj)
+        self.FirewallVersion = params.get("FirewallVersion")
 
 
 class DeleteFirewallRulesResponse(AbstractModel):
@@ -248,7 +281,7 @@ class DescribeBlueprintsRequest(AbstractModel):
 类型：String
 必选：否
 <li>blueprint-type</li>按照【镜像类型】进行过滤。
-取值： APP_OS（预置应用的系统 ）；PURE_OS（纯净的 OS 系统）。
+取值：APP_OS（预置应用的系统 ）；PURE_OS（纯净的 OS 系统）；PRIVATE（自定义镜像）。
 类型：String
 必选：否
 <li>platform-type</li>按照【镜像平台类型】进行过滤。
@@ -414,11 +447,14 @@ class DescribeFirewallRulesResponse(AbstractModel):
         :type TotalCount: int
         :param FirewallRuleSet: 防火墙规则详细信息列表。
         :type FirewallRuleSet: list of FirewallRuleInfo
+        :param FirewallVersion: 防火墙版本号。
+        :type FirewallVersion: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.TotalCount = None
         self.FirewallRuleSet = None
+        self.FirewallVersion = None
         self.RequestId = None
 
 
@@ -430,6 +466,7 @@ class DescribeFirewallRulesResponse(AbstractModel):
                 obj = FirewallRuleInfo()
                 obj._deserialize(item)
                 self.FirewallRuleSet.append(obj)
+        self.FirewallVersion = params.get("FirewallVersion")
         self.RequestId = params.get("RequestId")
 
 
@@ -600,18 +637,30 @@ class FirewallRule(AbstractModel):
 
     def __init__(self):
         """
-        :param Protocol: 协议，取值：TCP，UDP，ALL。
+        :param Protocol: 协议，取值：TCP，UDP，ICMP，ALL。
         :type Protocol: str
         :param Port: 端口，取值：ALL，单独的端口，逗号分隔的离散端口，减号分隔的端口范围。
         :type Port: str
+        :param CidrBlock: 网段或 IP (互斥)。默认为 0.0.0.0/0，表示所有来源。
+        :type CidrBlock: str
+        :param Action: 取值：ACCEPT，DROP。默认为 ACCEPT。
+        :type Action: str
+        :param FirewallRuleDescription: 防火墙规则描述。
+        :type FirewallRuleDescription: str
         """
         self.Protocol = None
         self.Port = None
+        self.CidrBlock = None
+        self.Action = None
+        self.FirewallRuleDescription = None
 
 
     def _deserialize(self, params):
         self.Protocol = params.get("Protocol")
         self.Port = params.get("Port")
+        self.CidrBlock = params.get("CidrBlock")
+        self.Action = params.get("Action")
+        self.FirewallRuleDescription = params.get("FirewallRuleDescription")
 
 
 class FirewallRuleInfo(AbstractModel):
@@ -621,22 +670,34 @@ class FirewallRuleInfo(AbstractModel):
 
     def __init__(self):
         """
-        :param AppType: 应用类型，取值：自定义，HTTP(80)，HTTPS(443)，Linux登录(22)，Windows登录(3389)，MySQL(3306)，SQL Server(1433)，全部TCP，全部UDP，ALL。
+        :param AppType: 应用类型，取值：自定义，HTTP(80)，HTTPS(443)，Linux登录(22)，Windows登录(3389)，MySQL(3306)，SQL Server(1433)，全部TCP，全部UDP，Ping-ICMP，ALL。
         :type AppType: str
-        :param Protocol: 协议，取值：TCP，UDP，ALL。
+        :param Protocol: 协议，取值：TCP，UDP，ICMP，ALL。
         :type Protocol: str
         :param Port: 端口，取值：ALL，单独的端口，逗号分隔的离散端口，减号分隔的端口范围。
         :type Port: str
+        :param CidrBlock: 网段或 IP (互斥)。默认为 0.0.0.0/0，表示所有来源。
+        :type CidrBlock: str
+        :param Action: 取值：ACCEPT，DROP。默认为 ACCEPT。
+        :type Action: str
+        :param FirewallRuleDescription: 防火墙规则描述。
+        :type FirewallRuleDescription: str
         """
         self.AppType = None
         self.Protocol = None
         self.Port = None
+        self.CidrBlock = None
+        self.Action = None
+        self.FirewallRuleDescription = None
 
 
     def _deserialize(self, params):
         self.AppType = params.get("AppType")
         self.Protocol = params.get("Protocol")
         self.Port = params.get("Port")
+        self.CidrBlock = params.get("CidrBlock")
+        self.Action = params.get("Action")
+        self.FirewallRuleDescription = params.get("FirewallRuleDescription")
 
 
 class Instance(AbstractModel):
@@ -1064,7 +1125,7 @@ class TrafficPackage(AbstractModel):
         """
         :param TrafficPackageId: 流量包ID。
         :type TrafficPackageId: str
-        :param TrafficUsed: 流量包生效周期内的总流量，单位字节。
+        :param TrafficUsed: 流量包生效周期内已使用流量，单位字节。
         :type TrafficUsed: int
         :param TrafficPackageTotal: 流量包生效周期内的总流量，单位字节。
         :type TrafficPackageTotal: int
